OC.L10N.register(
    "mail",
    {
    "Name" : "اسم",
    "Password" : "پاسورڈ",
    "Save" : "حفظ",
    "Connect" : "منسلک",
    "Send" : "بھجیں",
    "Select" : "Select",
    "Move" : "Move",
    "Delete" : "حذف کریں",
    "Choose" : "منتخب کریں",
    "Important" : "اہم",
    "Favorites" : "Favorites",
    "Other" : "دیگر",
    "Settings" : "سیٹینگز",
    "Add folder" : "Add folder",
    "Cancel" : "منسوخ کریں",
    "Reply" : "جواب",
    "User" : "User",
    "Search" : "Search"
},
"nplurals=2; plural=(n != 1);");
